package com.bwie.common.handler;

import com.alibaba.fastjson.JSONObject;
import com.bwie.common.result.Result;

import lombok.extern.log4j.Log4j2;
import org.springframework.context.annotation.Configuration;
import org.springframework.validation.ObjectError;
import org.springframework.web.bind.MethodArgumentNotValidException;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.RestControllerAdvice;

import java.util.stream.Collectors;

@RestControllerAdvice
@Log4j2
@Configuration
public class GlobalExceptionHandle {

    @ExceptionHandler(value = MethodArgumentNotValidException.class)
    public Result<String> runtimeException(MethodArgumentNotValidException exception){
        log.error("请求异常:[{}]",exception.getMessage(),exception);
        return Result.error(
                JSONObject.toJSONString(
                        exception.getBindingResult().getAllErrors()
                                .stream()
                                .map(ObjectError::getDefaultMessage)
                                .toArray()
                )
        );
//        return Result.error(
//        exception.getBindingResult().getAllErrors()
//                .stream()
//                .map(ObjectError::getDefaultMessage)
//                .collect(Collectors.joining()));
    }


    @ExceptionHandler(value = IllegalArgumentException.class)
    public Result<String> illegalArgumentExceptionHandle(IllegalArgumentException exception){
        log.error("请求异常[{}]",exception.getMessage(),exception);
        return Result.error(exception.getMessage());
    }












}
