package com.bwie.gateway.utils;

import com.alibaba.fastjson.JSONObject;
import com.bwie.common.result.Result;
import com.bwie.common.utils.StringUtils;

import org.springframework.core.io.buffer.DataBuffer;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpStatus;
import org.springframework.http.server.reactive.ServerHttpRequest;
import org.springframework.http.server.reactive.ServerHttpResponse;
import org.springframework.web.server.ServerWebExchange;
import reactor.core.publisher.Mono;

@Log4j2
public class GatewayUtils {
    public static void addHander(ServerHttpRequest.Builder mutate,String key,Object value) {
        if(StringUtils.isEmpty(key)){
            log.warn("添加请求头参数键不可以为空");
            return;
        }
        if(value==null){
            log.warn("添加请求头参数:[{}]值为空",key);
            return;
        }
        String string = value.toString();
        mutate.header(key,string);
        log.info("添加请求头参数成功 - 键:{[]},值:{[]}",key,value);
    }

    public static void removeHeader(ServerHttpRequest.Builder mutate, String key) {
        if (StringUtils.isEmpty(key)){
            log.warn("删除请求头参数键不可以为空");
            return;
        }
        mutate.headers(httpHeaders -> httpHeaders.remove(key)).build();
        log.info("删除请求头参数 - 键:[{}]",key);
    }

    public static Mono<Void> errorResponse(ServerWebExchange exchange,String msg){
        ServerHttpResponse response = exchange.getResponse();
        response.setStatusCode(HttpStatus.OK);
        response.getHeaders().add(HttpHeaders.CONTENT_TYPE,"application/json");
        Result<Object> error = Result.error(msg);
        String jsonString = JSONObject.toJSONString(error);
        log.error("[鉴权异常处理]请求路径:[{}],异常信息:[{}],响应结果:[{}]",
                exchange.getRequest().getPath(),msg,jsonString);
        DataBuffer wrap = response.bufferFactory().wrap(jsonString.getBytes());
        return response.writeWith(Mono.just(wrap));


    }














}
