package com.bwie.esask.seriver.impl;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.bwie.esask.mapper.EsAskRentMapper;
import com.bwie.esask.seriver.EsAskRentService;
import com.bwie.common.domain.AskRent;
import com.bwie.common.domain.request.AskRentRequest;
import com.bwie.common.redis.RedisCache;
import com.bwie.common.result.Result;
import org.elasticsearch.action.bulk.BulkRequest;
import org.elasticsearch.action.index.IndexRequest;
import org.elasticsearch.action.search.SearchRequest;
import org.elasticsearch.action.search.SearchResponse;
import org.elasticsearch.client.RequestOptions;
import org.elasticsearch.client.RestHighLevelClient;
import org.elasticsearch.index.query.BoolQueryBuilder;
import org.elasticsearch.index.query.QueryBuilders;
import org.elasticsearch.search.SearchHit;
import org.elasticsearch.search.SearchHits;
import org.elasticsearch.search.builder.SearchSourceBuilder;
import org.elasticsearch.xcontent.XContentType;
import org.springframework.stereotype.Service;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

/**
 * Es求租表
 */
@Service
public class EsAskRentServiceImpl extends ServiceImpl<EsAskRentMapper, AskRent> implements EsAskRentService {


    private final RedisCache redisCache;


    private final RestHighLevelClient client;

    public EsAskRentServiceImpl(RedisCache redisCache, RestHighLevelClient client) {
        this.redisCache = redisCache;
        this.client = client;
    }


    @Override
    public void shouListt(List<AskRent> list) {
        try {
            BulkRequest bulkRequest = new BulkRequest();
            list.forEach(askRent -> {
                bulkRequest.add(
                        new IndexRequest("askrent")
                                .id(JSON.toJSONString(askRent.getAskRentId()))
                                .source(JSON.toJSONString(askRent),XContentType.JSON)
                );
            });
            client.bulk(bulkRequest,RequestOptions.DEFAULT);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    //求购的链表
    @Override
    public Result shouRentList(AskRentRequest askRentRequest){
        ArrayList<AskRent> arrayList = new ArrayList<>();
        SearchRequest searchRequest = new SearchRequest("askrent");
        SearchSourceBuilder sourceBuilder = new SearchSourceBuilder();
        BoolQueryBuilder boolQueryBuilder = QueryBuilders.boolQuery();
        sourceBuilder.query(boolQueryBuilder);
        searchRequest.source(sourceBuilder);
        try {
            SearchResponse search = client.search(searchRequest, RequestOptions.DEFAULT);
            SearchHits hits = search.getHits();
            if(hits!=null){
                for (SearchHit hit : hits.getHits()) {
                    String sourceAsString = hit.getSourceAsString();
                    AskRent askRent = JSON.parseObject(sourceAsString, AskRent.class);
                    arrayList.add(askRent);
                }
            }
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        return Result.success(arrayList);
    }


}
